@@ -5,7 +5,7 @@ use warnings;
 
 use Call::Context ();
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 =encoding utf-8
 
@@ -21,6 +21,8 @@ Symbol::Get - Read Perl’s symbol table programmatically
     our @list = ( 1, 2, 3 );
     our %hash = ( foo => 1, bar => 2 );
 
+    use constant my_const => 'haha';
+
     sub doit { ... }
 
     my $name_sr = Symbol::Get::get('$Foo::name');    # \$name
@@ -30,6 +32,9 @@ Symbol::Get - Read Perl’s symbol table programmatically
     #Defaults to __PACKAGE__ if none is given:
     my $doit_cr = Symbol::Get::get('&doit');
 
+    #A constant--note the lack of sigil.
+    my $const_sr = Symbol::Get::get('Foo::my_const');
+
     #The below return the same results since get_names() defaults
     #to the current package if none is given.
     my @names = Symbol::Get::get_names('Foo');      # keys %Foo::
@@ -43,6 +48,20 @@ read-only interface to the symbol table.
 
 The SYNOPSIS above should pretty well cover usage.
 
+=head1 ABOUT PERL CONSTANTS
+
+This construction:
+
+    use constant foo => 'bar';
+
+… does something rather special with the symbol table: while you access
+C<foo> as though it were a function (e.g., C<foo()>, or just bareword C<foo>),
+the actual symbol table entry is a SCALAR reference, not a GLOB like other
+entries.
+
+C<Symbol::Get::get()> expects you to pass in names of constants WITHOUT
+trailing parens (C<()>), as in the example above.
+
 =head1 SEE ALSO
 
 =over 4
@@ -69,16 +88,30 @@ my $sigils_re_txt = join('|', keys %_sigil_to_type);
 sub get {
     my ($var) = @_;
 
-    die 'Need a variable name!' if !length $var;
+    die 'Need a variable or constant name!' if !length $var;
 
     my $sigil = substr($var, 0, 1);
 
+    goto \&_get_constant if $sigil =~ tr<A-Za-z_><>;
+
     my $type = $_sigil_to_type{$sigil} or die "Unrecognized sigil: “$sigil”";
 
     my $table_hr = _get_table_hr( substr($var, 1) );
     return $table_hr && *{$table_hr}{$type};
 }
 
+sub _get_constant {
+    my ($var) = @_;
+
+    my $ref = _get_table_hr($var);
+
+    if ('SCALAR' ne ref $ref) {
+        die "$var is a regular symbol table entry, not a constant.";
+    }
+
+    return $ref;
+}
+
 sub get_names {
     my ($module) = @_;
 
